@@ -9,3 +9,7 @@ version_info = pbr_version.VersionInfo('SeedboxManager')
 
 def version_string():
     return version_info.version_string()
+
+
+def release_string():
+    return version_info.release_string()
